import { default as React } from 'react';
import { Language } from './highlight.js';

export type CodeBlockProps = {
    /**
     * Your code (as text).
     */
    content: string;
    /**
     * Whether or not to apply syntax highlighting to the rendered code.
     *
     * @default true
     */
    highlighting?: boolean | undefined;
    /**
     * Whether or not to show a clipboard button which, when clicked, copies the current snippet to
     * the user clipboard.
     *
     * @default false
     */
    copiable?: boolean | undefined;
    /**
     * Specify the code language to apply syntax highlighting to the code block.
     *
     * @default text
     */
    language?: Language | undefined;
};
/**
 * A code block renders code in a pre-formatted monospace text block with syntax highlighting.
 *
 * ![Code block with syntax highlighting](./screenshots/code_block_with_highlighting.png)
 *
 * @param props
 * @example
 * ```tsx
 * import { CodeBlock } from "@netlify/sdk/ui/react/components";
 *
 * <CodeBlock content={`<p>Hello, world!</p>`} language="html" />
 * ```
 * @example
 * ```tsx
 * import { CodeBlock } from "@netlify/sdk/ui/react/components";
 *
 * <CodeBlock content={`<p>Hello, world!</p>`} />
 * ```
 */
export declare const CodeBlock: ({ content, highlighting, copiable, language, }: CodeBlockProps) => React.JSX.Element;
//# sourceMappingURL=CodeBlock.d.ts.map